@@ -1,10 +1,14 @@
 from __future__ import print_function
 
+import re
+
+import click
 import mock
 import pytest
 from click.testing import CliRunner
 
 from dagster.cli.schedule import (
+    check_repo_and_scheduler,
     schedule_list_command,
     schedule_logs_command,
     schedule_restart_command,
@@ -13,6 +17,9 @@ from dagster.cli.schedule import (
     schedule_up_command,
     schedule_wipe_command,
 )
+from dagster.core.host_representation import ExternalRepository
+from dagster.core.instance import DagsterInstance
+from dagster.core.test_utils import environ
 
 from .test_cli_commands import schedule_command_contexts
 
@@ -40,7 +47,9 @@ def test_schedules_up(gen_schedule_args):
             _instance.return_value = instance
             result = runner.invoke(schedule_up_command, cli_args,)
             assert result.exit_code == 0
-            assert "Changes:\n  + foo_schedule (add)" in result.output
+            assert "Changes:\n" in result.output
+            assert "  + foo_schedule (add)" in result.output
+            assert "  + partitioned_schedule (add)" in result.output
 
 
 @pytest.mark.parametrize("gen_schedule_args", schedule_command_contexts())
@@ -60,6 +69,9 @@ def test_schedules_up_and_list(gen_schedule_args):
                 "**************\n"
                 "Schedule: foo_schedule [STOPPED]\n"
                 "Cron Schedule: * * * * *\n"
+                "****************************************\n"
+                "Schedule: partitioned_schedule [STOPPED]\n"
+                "Cron Schedule: * * * * *\n"
             )
 
 
@@ -129,7 +141,9 @@ def test_schedules_wipe_correct_delete_message(gen_schedule_args):
 
             # Verify schedules were wiped
             assert result.exit_code == 0
-            assert "Planned Schedule Changes:\n  + foo_schedule (add)" in result.output
+            assert "Planned Schedule Changes:\n" in result.output
+            assert "  + partitioned_schedule (add)" in result.output
+            assert "  + foo_schedule (add)" in result.output
 
 
 @pytest.mark.parametrize("gen_schedule_args", schedule_command_contexts())
@@ -151,7 +165,7 @@ def test_schedules_wipe_incorrect_delete_message(gen_schedule_args):
             assert result.exit_code == 0
             assert (
                 result.output
-                == "No planned changes to schedules.\n1 schedules will remain unchanged\n"
+                == "No planned changes to schedules.\n2 schedules will remain unchanged\n"
             )
 
 
@@ -201,3 +215,36 @@ def test_schedules_logs(gen_schedule_args):
 
             assert result.exit_code == 0
             assert result.output.endswith("scheduler.log\n")
+
+
+def test_check_repo_and_scheduler_no_external_schedules():
+    repository = mock.MagicMock(spec=ExternalRepository)
+    repository.get_external_schedules.return_value = []
+    instance = mock.MagicMock(spec=DagsterInstance)
+    with pytest.raises(click.UsageError, match="There are no schedules defined for repository"):
+        check_repo_and_scheduler(repository, instance)
+
+
+def test_check_repo_and_scheduler_dagster_home_not_set():
+    repository = mock.MagicMock(spec=ExternalRepository)
+    repository.get_external_schedules.return_value = [mock.MagicMock()]
+    instance = mock.MagicMock(spec=DagsterInstance)
+
+    with pytest.raises(
+        click.UsageError, match=re.escape("The environment variable $DAGSTER_HOME is not set.")
+    ):
+        check_repo_and_scheduler(repository, instance)
+
+
+def test_check_repo_and_scheduler_instance_scheduler_not_set():
+    repository = mock.MagicMock(spec=ExternalRepository)
+    repository.get_external_schedules.return_value = [mock.MagicMock()]
+    instance = mock.MagicMock(spec=DagsterInstance)
+    type(instance).scheduler = mock.PropertyMock(return_value=None)
+
+    with environ({"DAGSTER_HOME": "~/dagster_home"}):
+        with pytest.raises(
+            click.UsageError,
+            match=re.escape("A scheduler must be configured to run schedule commands."),
+        ):
+            check_repo_and_scheduler(repository, instance)
