@@ -2,10 +2,11 @@
 # py27 compat
 
 import re
-from datetime import datetime
+from datetime import datetime, time
 
 import pytest
 from dateutil.relativedelta import relativedelta
+from freezegun import freeze_time
 
 from dagster import (
     Any,
@@ -23,6 +24,7 @@ from dagster import (
     execute_solid,
     lambda_solid,
     pipeline,
+    schedule,
     solid,
 )
 from dagster.core.definitions.decorators import (
@@ -31,6 +33,8 @@ from dagster.core.definitions.decorators import (
     monthly_schedule,
     weekly_schedule,
 )
+from dagster.core.definitions.schedule import ScheduleExecutionContext
+from dagster.core.test_utils import instance_for_test
 from dagster.core.utility_solids import define_stub_solid
 
 # This file tests a lot of parameter name stuff, so these warnings are spurious
@@ -308,6 +312,31 @@ def test_scheduler():
             )
         ]
 
+    @schedule(cron_schedule="* * * * *", pipeline_name="foo_pipeline")
+    def echo_time_schedule(context):
+        return {
+            "echo_time": (
+                (
+                    context.scheduled_execution_time_utc.isoformat()
+                    if context.scheduled_execution_time_utc
+                    else ""
+                )
+            )
+        }
+
+    with instance_for_test() as instance:
+        context_without_time = ScheduleExecutionContext(instance, None)
+
+        execution_time = datetime(year=2019, month=2, day=27)
+
+        context_with_time = ScheduleExecutionContext(instance, execution_time)
+
+        assert echo_time_schedule.get_run_config(context_without_time) == {"echo_time": ""}
+
+        assert echo_time_schedule.get_run_config(context_with_time) == {
+            "echo_time": execution_time.isoformat()
+        }
+
 
 def test_schedule_decorators_sanity():
     @solid
@@ -347,49 +376,149 @@ def test_schedule_decorators_sanity():
         return {}
 
 
-def _check_partitions(partition_schedule_def, expected_relative_delta):
+def _check_partitions(partition_schedule_def, expected_num_partitions, expected_relative_delta):
     partitions = partition_schedule_def.get_partition_set().partition_fn()
+    assert len(partitions) == expected_num_partitions
 
     for index, partition in enumerate(partitions):
         assert partition.value == partitions[0].value + (index * expected_relative_delta)
 
 
-def test_partitions_for_schedule_decorators():
-    @hourly_schedule(
-        pipeline_name="foo_pipeline", start_date=datetime(year=2019, month=1, day=1),
-    )
-    def hourly_foo_schedule():
-        return {}
+@freeze_time("2019-02-27 00:01:01")
+def test_partitions_for_hourly_schedule_decorators():
+    with instance_for_test() as instance:
 
-    _check_partitions(hourly_foo_schedule, relativedelta(hours=1))
+        context_without_time = ScheduleExecutionContext(instance, None)
 
-    @daily_schedule(
-        pipeline_name="foo_pipeline", start_date=datetime(year=2019, month=1, day=1),
-    )
-    def daily_foo_schedule():
-        return {}
+        @hourly_schedule(
+            pipeline_name="foo_pipeline",
+            start_date=datetime(year=2019, month=1, day=1, minute=1),
+            execution_time=time(hour=0, minute=25),
+        )
+        def hourly_foo_schedule(hourly_time):
+            return {"hourly_time": hourly_time.isoformat()}
 
-    _check_partitions(daily_foo_schedule, relativedelta(days=1))
+        _check_partitions(hourly_foo_schedule, 24 * (31 + 26), relativedelta(hours=1))
 
-    @weekly_schedule(
-        pipeline_name="foo_pipeline",
-        execution_day_of_week=1,
-        start_date=datetime(year=2019, month=1, day=1),
-    )
-    def weekly_foo_schedule():
-        return {}
+        assert hourly_foo_schedule.get_run_config(context_without_time) == {
+            "hourly_time": datetime(year=2019, month=2, day=26, hour=23, minute=1).isoformat()
+        }
+        assert hourly_foo_schedule.should_execute(context_without_time)
 
-    _check_partitions(weekly_foo_schedule, relativedelta(weeks=1))
+        # time that's invalid since it corresponds to a partition that hasn't happened yet
+        # should still generate run config, but should not execute
+        execution_time_with_invalid_partition = datetime(
+            year=2019, month=2, day=27, hour=3, minute=25
+        )
+        context_with_invalid_time = ScheduleExecutionContext(
+            instance, execution_time_with_invalid_partition
+        )
 
-    @monthly_schedule(
-        pipeline_name="foo_pipeline",
-        execution_day_of_month=3,
-        start_date=datetime(year=2019, month=1, day=1),
-    )
-    def monthly_foo_schedule():
-        return {}
+        assert hourly_foo_schedule.get_run_config(context_with_invalid_time) == {
+            "hourly_time": datetime(year=2019, month=2, day=27, hour=2, minute=1).isoformat()
+        }
 
-    _check_partitions(monthly_foo_schedule, relativedelta(months=1))
+        assert not hourly_foo_schedule.should_execute(context_with_invalid_time)
+
+        valid_time = datetime(year=2019, month=1, day=27, hour=1, minute=25)
+        context_with_valid_time = ScheduleExecutionContext(instance, valid_time)
+
+        assert hourly_foo_schedule.get_run_config(context_with_valid_time) == {
+            "hourly_time": datetime(year=2019, month=1, day=27, hour=0, minute=1).isoformat()
+        }
+
+        assert hourly_foo_schedule.should_execute(context_with_valid_time)
+
+
+@freeze_time("2019-02-27 00:01:01")
+def test_partitions_for_daily_schedule_decorators():
+    with instance_for_test() as instance:
+
+        context_without_time = ScheduleExecutionContext(instance, None)
+
+        @daily_schedule(
+            pipeline_name="foo_pipeline",
+            start_date=datetime(year=2019, month=1, day=1),
+            execution_time=time(hour=9, minute=30),
+        )
+        def daily_foo_schedule(daily_time):
+            return {"daily_time": daily_time.isoformat()}
+
+        _check_partitions(daily_foo_schedule, (31 + 26), relativedelta(days=1))
+
+        valid_daily_time = datetime(year=2019, month=1, day=27, hour=9, minute=30)
+        context_with_valid_time = ScheduleExecutionContext(instance, valid_daily_time)
+
+        assert daily_foo_schedule.get_run_config(context_with_valid_time) == {
+            "daily_time": datetime(year=2019, month=1, day=26).isoformat()
+        }
+        assert daily_foo_schedule.should_execute(context_with_valid_time)
+
+        assert daily_foo_schedule.get_run_config(context_without_time) == {
+            "daily_time": datetime(year=2019, month=2, day=26).isoformat()
+        }
+        assert daily_foo_schedule.should_execute(context_without_time)
+
+
+@freeze_time("2019-02-27 00:01:01")
+def test_partitions_for_weekly_schedule_decorators():
+    with instance_for_test() as instance:
+        context_without_time = ScheduleExecutionContext(instance, None)
+
+        @weekly_schedule(
+            pipeline_name="foo_pipeline",
+            execution_day_of_week=2,
+            start_date=datetime(year=2019, month=1, day=1),
+            execution_time=time(9, 30),
+        )
+        def weekly_foo_schedule(weekly_time):
+            return {"weekly_time": weekly_time.isoformat()}
+
+        valid_weekly_time = datetime(year=2019, month=1, day=30, hour=9, minute=30)
+        context_with_valid_time = ScheduleExecutionContext(instance, valid_weekly_time)
+
+        assert weekly_foo_schedule.get_run_config(context_with_valid_time) == {
+            "weekly_time": datetime(year=2019, month=1, day=22).isoformat()
+        }
+
+        assert weekly_foo_schedule.should_execute(context_with_valid_time)
+
+        assert weekly_foo_schedule.get_run_config(context_without_time) == {
+            "weekly_time": datetime(year=2019, month=2, day=19).isoformat()
+        }
+        assert weekly_foo_schedule.should_execute(context_without_time)
+
+        _check_partitions(weekly_foo_schedule, 8, relativedelta(weeks=1))
+
+
+@freeze_time("2019-02-27 00:01:01")
+def test_partitions_for_monthly_schedule_decorators():
+    with instance_for_test() as instance:
+        context_without_time = ScheduleExecutionContext(instance, None)
+
+        @monthly_schedule(
+            pipeline_name="foo_pipeline",
+            execution_day_of_month=3,
+            start_date=datetime(year=2019, month=1, day=1),
+            execution_time=time(9, 30),
+        )
+        def monthly_foo_schedule(monthly_time):
+            return {"monthly_time": monthly_time.isoformat()}
+
+        valid_monthly_time = datetime(year=2019, month=2, day=3, hour=9, minute=30)
+        context_with_valid_time = ScheduleExecutionContext(instance, valid_monthly_time)
+
+        assert monthly_foo_schedule.get_run_config(
+            ScheduleExecutionContext(instance, valid_monthly_time)
+        ) == {"monthly_time": datetime(year=2019, month=1, day=1).isoformat()}
+        assert monthly_foo_schedule.should_execute(context_with_valid_time)
+
+        assert monthly_foo_schedule.get_run_config(context_without_time) == {
+            "monthly_time": datetime(year=2019, month=1, day=1).isoformat()
+        }
+        assert monthly_foo_schedule.should_execute(context_without_time)
+
+        _check_partitions(monthly_foo_schedule, 1, relativedelta(months=1))
 
 
 def test_schedule_decorators_bad():
