@@ -3,11 +3,11 @@ import time
 
 import pytest
 
-from dagster import solid, Output, PipelineDefinition, execute_pipeline
+from dagster import Output, PipelineDefinition, execute_pipeline, solid
 
 
 @pytest.mark.skipif(
-    sys.platform == 'win32', reason='https://github.com/dagster-io/dagster/issues/1421'
+    sys.platform == "win32", reason="https://github.com/dagster-io/dagster/issues/1421"
 )
 def test_event_timing_before_yield():
     @solid
@@ -17,12 +17,12 @@ def test_event_timing_before_yield():
 
     pipeline_def = PipelineDefinition(solid_defs=[before_yield_solid])
     pipeline_result = execute_pipeline(pipeline_def)
-    success_event = pipeline_result.result_for_solid('before_yield_solid').get_step_success_event()
+    success_event = pipeline_result.result_for_solid("before_yield_solid").get_step_success_event()
     assert success_event.event_specific_data.duration_ms >= 10.0
 
 
 @pytest.mark.skipif(
-    sys.platform == 'win32', reason='https://github.com/dagster-io/dagster/issues/1421'
+    sys.platform == "win32", reason="https://github.com/dagster-io/dagster/issues/1421"
 )
 def test_event_timing_after_yield():
     @solid
@@ -32,12 +32,12 @@ def test_event_timing_after_yield():
 
     pipeline_def = PipelineDefinition(solid_defs=[after_yield_solid])
     pipeline_result = execute_pipeline(pipeline_def)
-    success_event = pipeline_result.result_for_solid('after_yield_solid').get_step_success_event()
+    success_event = pipeline_result.result_for_solid("after_yield_solid").get_step_success_event()
     assert success_event.event_specific_data.duration_ms >= 10.0
 
 
 @pytest.mark.skipif(
-    sys.platform == 'win32', reason='https://github.com/dagster-io/dagster/issues/1421'
+    sys.platform == "win32", reason="https://github.com/dagster-io/dagster/issues/1421"
 )
 def test_event_timing_direct_return():
     @solid
@@ -47,5 +47,5 @@ def test_event_timing_direct_return():
 
     pipeline_def = PipelineDefinition(solid_defs=[direct_return_solid])
     pipeline_result = execute_pipeline(pipeline_def)
-    success_event = pipeline_result.result_for_solid('direct_return_solid').get_step_success_event()
+    success_event = pipeline_result.result_for_solid("direct_return_solid").get_step_success_event()
     assert success_event.event_specific_data.duration_ms >= 10.0
