@@ -2,7 +2,6 @@ import csv
 import os
 import time
 from collections import OrderedDict
-from contextlib import contextmanager
 from copy import deepcopy
 
 from dagster import (
@@ -20,26 +19,25 @@ from dagster import (
     lambda_solid,
     pipeline,
     reconstructable,
-    seven,
     solid,
 )
 from dagster.core.events import DagsterEventType
 from dagster.core.host_representation.handle import RepositoryHandle, RepositoryLocationHandle
-from dagster.core.instance import DagsterInstance
 from dagster.core.storage.pipeline_run import PipelineRunStatus
+from dagster.core.test_utils import instance_for_test
 from dagster.utils import file_relative_path, safe_tempfile_path
 from dagster.utils.hosted_user_process import external_pipeline_from_recon_pipeline
 
 
 @dagster_type_loader(String)
 def df_input_schema(_context, path):
-    with open(path, 'r') as fd:
+    with open(path, "r") as fd:
         return [OrderedDict(sorted(x.items(), key=lambda x: x[0])) for x in csv.DictReader(fd)]
 
 
 @dagster_type_materializer(String)
 def df_output_schema(_context, path, value):
-    with open(path, 'w') as fd:
+    with open(path, "w") as fd:
         writer = csv.DictWriter(fd, fieldnames=value[0].keys())
         writer.writeheader()
         writer.writerows(rowdicts=value)
@@ -49,33 +47,33 @@ def df_output_schema(_context, path, value):
 
 PoorMansDataFrame = PythonObjectDagsterType(
     python_type=list,
-    name='PoorMansDataFrame',
+    name="PoorMansDataFrame",
     loader=df_input_schema,
     materializer=df_output_schema,
 )
 
 
 @lambda_solid(
-    input_defs=[InputDefinition('num', PoorMansDataFrame)],
+    input_defs=[InputDefinition("num", PoorMansDataFrame)],
     output_def=OutputDefinition(PoorMansDataFrame),
 )
 def sum_solid(num):
     sum_df = deepcopy(num)
     for x in sum_df:
-        x['sum'] = x['num1'] + x['num2']
+        x["sum"] = x["num1"] + x["num2"]
     return sum_df
 
 
 @lambda_solid(
-    input_defs=[InputDefinition('sum_df', PoorMansDataFrame)],
+    input_defs=[InputDefinition("sum_df", PoorMansDataFrame)],
     output_def=OutputDefinition(PoorMansDataFrame),
 )
 def error_solid(sum_df):  # pylint: disable=W0613
-    raise Exception('foo')
+    raise Exception("foo")
 
 
 @lambda_solid(
-    input_defs=[InputDefinition('sum_df', PoorMansDataFrame)],
+    input_defs=[InputDefinition("sum_df", PoorMansDataFrame)],
     output_def=OutputDefinition(PoorMansDataFrame),
 )
 def crashy_solid(sum_df):  # pylint: disable=W0613
@@ -97,14 +95,14 @@ def crashy_pipeline():
     crashy_solid(sum_solid())
 
 
-@solid(config_schema={'foo': Field(String)})
+@solid(config_schema={"foo": Field(String)})
 def node_a(context):
-    return context.solid_config['foo']
+    return context.solid_config["foo"]
 
 
-@solid(config_schema={'bar': Int})
+@solid(config_schema={"bar": Int})
 def node_b(context, input_):
-    return input_ * context.solid_config['bar']
+    return input_ * context.solid_config["bar"]
 
 
 @composite_solid
@@ -119,10 +117,10 @@ def composite_pipeline():
 
 @composite_solid(
     config_fn=lambda cfg: {
-        'node_a': {'config': {'foo': cfg['foo']}},
-        'node_b': {'config': {'bar': cfg['bar']}},
+        "node_a": {"config": {"foo": cfg["foo"]}},
+        "node_b": {"config": {"bar": cfg["bar"]}},
     },
-    config_schema={'foo': Field(String), 'bar': Int},
+    config_schema={"foo": Field(String), "bar": Int},
 )
 def composite_with_nested_config_solid_and_config_mapping():
     return node_b(node_a())
@@ -141,20 +139,10 @@ def get_events_of_type(events, event_type):
     ]
 
 
-@contextmanager
-def temp_instance():
-    with seven.TemporaryDirectory() as temp_dir:
-        instance = DagsterInstance.local_temp(temp_dir)
-        try:
-            yield instance
-        finally:
-            instance.run_launcher.join()
-
-
 def test_works_in_memory():
 
     run_config = {
-        'solids': {'sum_solid': {'inputs': {'num': file_relative_path(__file__, 'data/num.csv')}}}
+        "solids": {"sum_solid": {"inputs": {"num": file_relative_path(__file__, "data/num.csv")}}}
     }
     assert execute_pipeline(passing_pipeline, run_config).success
 
@@ -165,9 +153,7 @@ def _external_pipeline_from_def(pipeline_def, solid_selection=None):
     repo_def = recon_repo.get_definition()
     location_handle = RepositoryLocationHandle.create_in_process_location(recon_repo.pointer)
     repository_handle = RepositoryHandle(
-        repository_name=repo_def.name,
-        repository_key=repo_def.name,
-        repository_location_handle=location_handle,
+        repository_name=repo_def.name, repository_location_handle=location_handle,
     )
     return external_pipeline_from_recon_pipeline(
         reconstructable(pipeline_def),
@@ -193,10 +179,10 @@ def _execute_in_launcher(instance, pipeline_def, run_config, solid_selection=Non
 
 def test_running():
     run_config = {
-        'solids': {'sum_solid': {'inputs': {'num': file_relative_path(__file__, 'data/num.csv')}}}
+        "solids": {"sum_solid": {"inputs": {"num": file_relative_path(__file__, "data/num.csv")}}}
     }
 
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         pipeline_run = _execute_in_launcher(instance, passing_pipeline, run_config)
 
         assert instance.get_run_by_id(pipeline_run.run_id).status == PipelineRunStatus.SUCCESS
@@ -215,10 +201,10 @@ def test_running():
 
 
 def test_failing():
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         run_config = {
-            'solids': {
-                'sum_solid': {'inputs': {'num': file_relative_path(__file__, 'data/num.csv')}}
+            "solids": {
+                "sum_solid": {"inputs": {"num": file_relative_path(__file__, "data/num.csv")}}
             }
         }
 
@@ -230,10 +216,10 @@ def test_failing():
 
 def test_execution_crash():
     run_config = {
-        'solids': {'sum_solid': {'inputs': {'num': file_relative_path(__file__, 'data/num.csv')}}}
+        "solids": {"sum_solid": {"inputs": {"num": file_relative_path(__file__, "data/num.csv")}}}
     }
 
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
 
         pipeline_run = _execute_in_launcher(instance, crashy_pipeline, run_config)
 
@@ -243,7 +229,7 @@ def test_execution_crash():
         ]  # last message is pipeline failure, second to last is...
 
         assert crash_log.message.startswith(
-            '[CliApiRunLauncher] Pipeline execution process for {run_id} unexpectedly exited'.format(
+            "[CliApiRunLauncher] Pipeline execution process for {run_id} unexpectedly exited".format(
                 run_id=pipeline_run.run_id
             )
         )
@@ -251,43 +237,43 @@ def test_execution_crash():
 
 def test_multiprocessing_execution_for_composite_solid():
     run_config = {
-        'solids': {
-            'composite_with_nested_config_solid': {
-                'solids': {'node_a': {'config': {'foo': 'baz'}}, 'node_b': {'config': {'bar': 3}}}
+        "solids": {
+            "composite_with_nested_config_solid": {
+                "solids": {"node_a": {"config": {"foo": "baz"}}, "node_b": {"config": {"bar": 3}}}
             }
         }
     }
 
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         pipeline_run = _execute_in_launcher(instance, composite_pipeline, run_config)
         assert instance.get_run_by_id(pipeline_run.run_id).status == PipelineRunStatus.SUCCESS
 
 
 def test_multiprocessing_execution_for_composite_solid_multiprocess_executor():
     run_config = {
-        'solids': {
-            'composite_with_nested_config_solid': {
-                'solids': {'node_a': {'config': {'foo': 'baz'}}, 'node_b': {'config': {'bar': 3}}}
+        "solids": {
+            "composite_with_nested_config_solid": {
+                "solids": {"node_a": {"config": {"foo": "baz"}}, "node_b": {"config": {"bar": 3}}}
             }
         },
-        'execution': {'multiprocess': {}},
-        'storage': {'filesystem': {}},
+        "execution": {"multiprocess": {}},
+        "storage": {"filesystem": {}},
     }
 
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         second_run = _execute_in_launcher(instance, composite_pipeline, run_config)
         assert instance.get_run_by_id(second_run.run_id).status == PipelineRunStatus.SUCCESS
 
 
 def test_multiprocessing_execution_for_composite_solid_with_config_mapping():
     run_config = {
-        'solids': {
-            'composite_with_nested_config_solid_and_config_mapping': {
-                'config': {'foo': 'baz', 'bar': 3}
+        "solids": {
+            "composite_with_nested_config_solid_and_config_mapping": {
+                "config": {"foo": "baz", "bar": 3}
             }
         }
     }
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         pipeline_run = _execute_in_launcher(
             instance, pipeline_def=composite_pipeline_with_config_mapping, run_config=run_config,
         )
@@ -296,25 +282,25 @@ def test_multiprocessing_execution_for_composite_solid_with_config_mapping():
 
 def test_multiprocessing_execution_for_composite_solid_with_config_mapping_with_multiprocess():
     run_config = {
-        'solids': {
-            'composite_with_nested_config_solid_and_config_mapping': {
-                'config': {'foo': 'baz', 'bar': 3}
+        "solids": {
+            "composite_with_nested_config_solid_and_config_mapping": {
+                "config": {"foo": "baz", "bar": 3}
             },
         },
-        'execution': {'multiprocess': {}},
-        'storage': {'filesystem': {}},
+        "execution": {"multiprocess": {}},
+        "storage": {"filesystem": {}},
     }
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         pipeline_run = _execute_in_launcher(
             instance, pipeline_def=composite_pipeline_with_config_mapping, run_config=run_config,
         )
         assert instance.get_run_by_id(pipeline_run.run_id).status == PipelineRunStatus.SUCCESS
 
 
-@solid(config_schema={'file': Field(String)})
+@solid(config_schema={"file": Field(String)})
 def loop(context):
-    with open(context.solid_config['file'], 'w') as ff:
-        ff.write('yup')
+    with open(context.solid_config["file"], "w") as ff:
+        ff.write("yup")
 
     while True:
         time.sleep(0.1)
@@ -326,9 +312,9 @@ def infinite_loop_pipeline():
 
 
 def test_has_run_query_and_terminate():
-    with temp_instance() as instance:
+    with instance_for_test() as instance:
         with safe_tempfile_path() as path:
-            run_config = {'solids': {'loop': {'config': {'file': path}}}}
+            run_config = {"solids": {"loop": {"config": {"file": path}}}}
 
             created_pipeline_run = instance.create_run_for_pipeline(
                 pipeline_def=infinite_loop_pipeline, run_config=run_config,
@@ -355,10 +341,10 @@ def test_has_run_query_and_terminate():
 
 
 def test_two_runs_running():
-    with safe_tempfile_path() as file_one, safe_tempfile_path() as file_two, temp_instance() as instance:
+    with safe_tempfile_path() as file_one, safe_tempfile_path() as file_two, instance_for_test() as instance:
         pipeline_run_one = instance.create_run_for_pipeline(
             pipeline_def=infinite_loop_pipeline,
-            run_config={'solids': {'loop': {'config': {'file': file_one}}}},
+            run_config={"solids": {"loop": {"config": {"file": file_one}}}},
         )
         instance.launch_run(
             pipeline_run_one.run_id, _external_pipeline_from_def(infinite_loop_pipeline)
@@ -366,7 +352,7 @@ def test_two_runs_running():
 
         pipeline_run_two = instance.create_run_for_pipeline(
             pipeline_def=infinite_loop_pipeline,
-            run_config={'solids': {'loop': {'config': {'file': file_two}}}},
+            run_config={"solids": {"loop": {"config": {"file": file_two}}}},
         )
 
         instance.launch_run(
