@@ -6,11 +6,13 @@ import pytest
 
 from dagster import file_relative_path, pipeline, repository, seven, solid
 from dagster.core.definitions.reconstructable import ReconstructableRepository
+from dagster.core.errors import DagsterLaunchFailedError
 from dagster.core.host_representation.handle import RepositoryLocationHandle
 from dagster.core.host_representation.repository_location import GrpcServerRepositoryLocation
 from dagster.core.instance import DagsterInstance
 from dagster.core.launcher.grpc_run_launcher import GrpcRunLauncher
 from dagster.core.storage.pipeline_run import PipelineRunStatus
+from dagster.core.storage.tags import GRPC_INFO_TAG
 from dagster.core.test_utils import (
     instance_for_test,
     poll_for_event,
@@ -19,6 +21,7 @@ from dagster.core.test_utils import (
 )
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster.grpc.server import GrpcServerProcess
+from dagster.utils import find_free_port, merge_dicts
 
 
 @solid
@@ -113,7 +116,7 @@ def test_repo_construction():
 def get_external_pipeline_from_grpc_server_repository(pipeline_name):
     repo_yaml = file_relative_path(__file__, "repo.yaml")
     recon_repo = ReconstructableRepository.from_legacy_repository_yaml(repo_yaml)
-    loadable_target_origin = LoadableTargetOrigin.from_python_origin(recon_repo.get_origin())
+    loadable_target_origin = recon_repo.get_origin().loadable_target_origin
     server_process = GrpcServerProcess(loadable_target_origin=loadable_target_origin)
 
     try:
@@ -195,7 +198,7 @@ def test_run_always_finishes():  # pylint: disable=redefined-outer-name
         run_id = pipeline_run.run_id
 
         recon_repo = ReconstructableRepository.for_file(__file__, "nope")
-        loadable_target_origin = LoadableTargetOrigin.from_python_origin(recon_repo.get_origin())
+        loadable_target_origin = recon_repo.get_origin().loadable_target_origin
 
         server_process = GrpcServerProcess(
             loadable_target_origin=loadable_target_origin, max_workers=4
@@ -278,6 +281,53 @@ def test_crashy_run(get_external_pipeline):  # pylint: disable=redefined-outer-n
             assert _message_exists(event_records, message)
 
 
+def test_terminate_after_shutdown():
+    with grpc_instance() as instance:
+        repository_location_handle = RepositoryLocationHandle.create_process_bound_grpc_server_location(
+            loadable_target_origin=LoadableTargetOrigin(
+                attribute="nope",
+                python_file=file_relative_path(__file__, "test_cli_api_run_launcher.py"),
+            ),
+            location_name="nope",
+        )
+        repository_location = GrpcServerRepositoryLocation(repository_location_handle)
+
+        external_pipeline = repository_location.get_repository("nope").get_full_external_pipeline(
+            "sleepy_pipeline"
+        )
+
+        pipeline_run = instance.create_run_for_pipeline(
+            pipeline_def=sleepy_pipeline, run_config=None
+        )
+
+        launcher = instance.run_launcher
+        launcher.launch_run(instance, pipeline_run, external_pipeline)
+
+        poll_for_step_start(instance, pipeline_run.run_id)
+
+        # Tell the server to shut down once executions finish
+        repository_location_handle.client.cleanup_server()
+
+        # Trying to start another run fails
+        doomed_to_fail_external_pipeline = repository_location.get_repository(
+            "nope"
+        ).get_full_external_pipeline("math_diamond")
+        doomed_to_fail_pipeline_run = instance.create_run_for_pipeline(
+            pipeline_def=math_diamond, run_config=None
+        )
+
+        with pytest.raises(DagsterLaunchFailedError):
+            launcher.launch_run(
+                instance, doomed_to_fail_pipeline_run, doomed_to_fail_external_pipeline
+            )
+
+        # Can terminate the run even after the shutdown event has been received
+        assert launcher.can_terminate(pipeline_run.run_id)
+        assert launcher.terminate(pipeline_run.run_id)
+
+        # Server process now shuts down cleanly since there are no more executions
+
+
 @pytest.mark.parametrize(
     "get_external_pipeline",
     [
@@ -304,6 +354,9 @@ def test_terminated_run(get_external_pipeline):  # pylint: disable=redefined-out
             assert launcher.can_terminate(run_id)
             assert launcher.terminate(run_id)
 
+            # can_terminate returns False once termination has starte
+            assert not launcher.can_terminate(run_id)
+
             terminated_pipeline_run = poll_for_finished_run(instance, run_id, timeout=30)
             terminated_pipeline_run = instance.get_run_by_id(run_id)
             assert terminated_pipeline_run.status == PipelineRunStatus.FAILURE
@@ -319,6 +372,7 @@ def test_terminated_run(get_external_pipeline):  # pylint: disable=redefined-out
                 "PIPELINE_START",
                 "ENGINE_EVENT",
                 "STEP_START",
+                "ENGINE_EVENT",
                 "STEP_FAILURE",
                 "PIPELINE_FAILURE",
                 "ENGINE_EVENT",
@@ -465,3 +519,61 @@ def test_not_initialized():  # pylint: disable=redefined-outer-name
     assert run_launcher.join() is None
     assert run_launcher.can_terminate(run_id) is False
     assert run_launcher.terminate(run_id) is False
+
+
+def test_server_down():
+    with grpc_instance() as instance:
+        repo_yaml = file_relative_path(__file__, "repo.yaml")
+        recon_repo = ReconstructableRepository.from_legacy_repository_yaml(repo_yaml)
+        loadable_target_origin = recon_repo.get_origin().loadable_target_origin
+        server_process = GrpcServerProcess(
+            loadable_target_origin=loadable_target_origin, max_workers=4, force_port=True
+        )
+
+        with server_process.create_ephemeral_client() as api_client:
+            repository_location = GrpcServerRepositoryLocation(
+                RepositoryLocationHandle.create_grpc_server_location(
+                    location_name="test",
+                    port=api_client.port,
+                    socket=api_client.socket,
+                    host=api_client.host,
+                )
+            )
+
+            external_pipeline = repository_location.get_repository(
+                "nope"
+            ).get_full_external_pipeline("sleepy_pipeline")
+
+            pipeline_run = instance.create_run_for_pipeline(
+                pipeline_def=sleepy_pipeline, run_config=None
+            )
+
+            launcher = instance.run_launcher
+
+            launcher.launch_run(instance, pipeline_run, external_pipeline)
+
+            poll_for_step_start(instance, pipeline_run.run_id)
+
+            assert launcher.can_terminate(pipeline_run.run_id)
+
+            original_run_tags = instance.get_run_by_id(pipeline_run.run_id).tags[GRPC_INFO_TAG]
+
+            # Replace run tags with an invalid port
+            instance.add_run_tags(
+                pipeline_run.run_id,
+                {
+                    GRPC_INFO_TAG: seven.json.dumps(
+                        merge_dicts({"host": "localhost"}, {"port": find_free_port()})
+                    )
+                },
+            )
+
+            assert not launcher.can_terminate(pipeline_run.run_id)
+
+            instance.add_run_tags(
+                pipeline_run.run_id, {GRPC_INFO_TAG: original_run_tags,},
+            )
+
+            assert launcher.terminate(pipeline_run.run_id)
+
+        server_process.wait()
